==> cicada-0.0.2.tgz: package/README.md <==
# Cicada Language

A nascent programming language as formal deduction system for the foundations of mathematics.

## Contents

**partech**: Parsing Techniques, with DSL for CFG and general CFG parsers.
- CFG: https://en.wikipedia.org/wiki/Context-free_grammar
- Earley parser: https://en.wikipedia.org/wiki/Earley_parser
- IXML: https://homepages.cwi.nl/~steven/ixml

**lang0**: Untyped lambda calculus.
- https://en.wikipedia.org/wiki/Lambda_calculus

**lang1**: Simply typed lambda calculus, with natural number and primitve recursion.
- https://en.wikipedia.org/wiki/Simply_typed_lambda_calculus
- System T: https://en.wikipedia.org/wiki/Dialectica_interpretation

**lang2**: Tartlet, pie and "The Little typer".
- Racket implementation: https://davidchristiansen.dk/tutorials/nbe
- Haskell implementation: https://davidchristiansen.dk/tutorials/implementing-types-hs.pdf

## References

- [How I became interested in foundations of mathematics](https://inner-universe.now.sh/person/vladimir-voevodsky/how-i-became-interested-in-foundations-of-mathematics.md.html)
  - by Vladimir Voevodsky, at the 9th Asian Science Camp, Thailand, 2015
- [Lecture about Univalent Foundations at the Institut Henri Poincaré](https://inner-universe.now.sh/person/vladimir-voevodsky/lecture-about-univalent-foundations-at-the-institut-henri-poincar%C3%A9.md.html)
  - by Vladimir Voevodsky, at the Institut Henri Poincaré, 2014

## Community

Contributions are welcome, see [current TODO list](TODO.md) for tasks. <br>
(Please add yourself to [the AUTHORS list](AUTHORS) if you made any contributions.)

- We enforce C4 as collaboration protocol.
  - [The C4 RFC](https://rfc.zeromq.org/spec:42/C4)
- [Style Guide](STYLE-GUIDE.md)
  - Observe the style of existing code and respect it.
- [Code of Conduct](CODE-OF-CONDUCT.md)

## License

- [GPLv3](LICENSE)

==> cicada-0.0.3.tgz: package/README.md <==
# Cicada Language

A nascent programming language as formal deduction system for the foundations of mathematics.

## Contents

**partech**: Parsing Techniques, with DSL for CFG and general CFG parsers.
- CFG: https://en.wikipedia.org/wiki/Context-free_grammar
- Earley parser: https://en.wikipedia.org/wiki/Earley_parser
- IXML: https://homepages.cwi.nl/~steven/ixml

**lang0**: untyped lambda calculus.
- https://en.wikipedia.org/wiki/Lambda_calculus

**lang1**: simply typed lambda calculus, natural number, primitve recursive combinator.
- https://en.wikipedia.org/wiki/Simply_typed_lambda_calculus
- System T: https://en.wikipedia.org/wiki/Dialectica_interpretation

**lang2**: Pie and "The Little typer", "Type in Type", no recursion.
- Racket implementation: https://davidchristiansen.dk/tutorials/nbe
- Haskell implementation: https://davidchristiansen.dk/tutorials/implementing-types-hs.pdf

**lang3**: dependent type, structural type, fulfilling type, "Type in Type", module system, arbitrary module-level recursion.

## References

- [How I became interested in foundations of mathematics](https://inner-universe.now.sh/person/vladimir-voevodsky/how-i-became-interested-in-foundations-of-mathematics.md.html)
  - by Vladimir Voevodsky, at the 9th Asian Science Camp, Thailand, 2015
- [Lecture about Univalent Foundations at the Institut Henri Poincaré](https://inner-universe.now.sh/person/vladimir-voevodsky/lecture-about-univalent-foundations-at-the-institut-henri-poincar%C3%A9.md.html)
  - by Vladimir Voevodsky, at the Institut Henri Poincaré, 2014

## Community

Contributions are welcome, see [current TODO list](TODO.md) for tasks. <br>
(Please add yourself to [the AUTHORS list](AUTHORS) if you made any contributions.)

- We enforce C4 as collaboration protocol.
  - [The C4 RFC](https://rfc.zeromq.org/spec:42/C4)
- [Style Guide](STYLE-GUIDE.md)
  - Observe the style of existing code and respect it.
- [Code of Conduct](CODE-OF-CONDUCT.md)

## License

- [GPLv3](LICENSE)
